@@ -14,7 +14,9 @@ require AutoLoader;
 # Items to export to callers namespace
 @EXPORT = qw();
 
-$VERSION = '0.9';
+$VERSION = '1.1';
+
+=pod
 
 =head1 NAME
 
@@ -55,6 +57,7 @@ It provides the following features:
 The entire proces is configurable, so you can pick and choose what you want
 to clean.
 
+=cut
 =head1 THE HTML::Clean CLASS
 
 =over 4
@@ -64,7 +67,7 @@ to clean.
 
 ######################################################################
 
-=head2 $h = new HTML::Clean($dataorfile, [$level]);
+=head2 $h = HTML::Clean->new($dataorfile, [$level]);
 
 This creates a new HTML::Clean object.  A Prerequisite for all other
 functions in this module.
@@ -72,9 +75,9 @@ functions in this module.
 The $dataorfile parameter supplies the input HTML, either a filename,
 or a reference to a scalar value holding the HTML, for example:
 
-  $h = new HTML::Clean("/htdocs/index.html");
+  $h = HTML::Clean->new("/htdocs/index.html");
   $html = "<strong>Hello!</strong>";
-  $h = new HTML::Clean(\$html);
+  $h = HTML::Clean->new(\$html);
 
 An optional 'level' parameter controls the level of optimization
 performed.  Levels range from 1 to 9.  Level 1 includes only simple
@@ -656,7 +659,7 @@ sub defrontpage {
   }
   $$h =~ s,<!--(mstheme|msthemeseparator|msnavigation)-->,,sgx;
 }
-=back
+
 
 =head1 SEE ALSO
 
